@@ -16,7 +16,7 @@ use experimental qw( lexical_subs signatures );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.4.0';
+our $VERSION = 'v0.4.1';
 
 
 has policy => (
@@ -26,9 +26,9 @@ has policy => (
 
 
 has name => (
-    is        => 'ro',
-    isa       => Maybe [NonEmptySimpleStr],
-    predicate => 1,
+    is      => 'ro',
+    isa     => Maybe [NonEmptySimpleStr],
+    default => sub { return undef },
 );
 
 
@@ -97,7 +97,7 @@ has fulltext => (
             STRICT  => 1,
             BROKEN  => sub(%args) { die $args{error} },
             HASH    => {
-                name    => $self->name,
+                name    => $self->name // "",
                 contact => $self->contact,
                 entity  => $self->entity,
                 Entity  => $self->Entity,
@@ -149,7 +149,7 @@ Software::Policy::CodeOfConduct - generate a Code of Conduct policy
 
 =head1 VERSION
 
-version v0.4.0
+version v0.4.1
 
 =head1 SYNOPSIS
 
@@ -197,10 +197,6 @@ If you want to use a custom policy, specify the L</template_path>.
 
 This is the (optional) name of the project that the code of conduct is for,
 
-=head2 has_name
-
-True if there is a name.
-
 =head2 contact
 
 The is the contact for the project team about the code of conduct. It should be an email address or a URL.
@@ -251,11 +247,6 @@ This saves a file named L</filename> in directory C<$dir>.
 
 If C<$dir> is omitted, then it will save the file in the current directory.
 
-=head1 SOURCE
-
-The development version is on github at L<https://github.com/robrwo/perl-Software-Policy-CodeOfConduct>
-and may be cloned from L<git://github.com/robrwo/perl-Software-Policy-CodeOfConduct.git>
-
 =head1 SUPPORT
 
 Only the latest version of this module will be supported.
@@ -275,6 +266,11 @@ feature.
 If the bug you are reporting has security implications which make it inappropriate to send to a public issue tracker,
 then see F<SECURITY.md> for instructions how to report security vulnerabilities.
 
+=head1 SOURCE
+
+The development version is on github at L<https://github.com/robrwo/perl-Software-Policy-CodeOfConduct>
+and may be cloned from L<git://github.com/robrwo/perl-Software-Policy-CodeOfConduct.git>
+
 =head1 AUTHOR
 
 Robert Rothenberg <rrwo@cpan.org>
